caellion-python-commons: caellion/pycommons/stringutil/unixpassword.py File Reference

caellion-python-commons

Classes | Namespaces
unixpassword.py File Reference

Go to the source code of this file.

## Classes
class | caellion.pycommons.stringutil.unixpassword.DuplicateFieldException
| This exception is raised when more than exactly one instance of a given field is contained within field list. More...
class | caellion.pycommons.stringutil.unixpassword.EmptyFieldNameException
| This exception is raised when an empty field name is encountered. More...
class | caellion.pycommons.stringutil.unixpassword.SeparatorEmptyException
| This exception is raised when an empty separator string is encountered. More...
class | caellion.pycommons.stringutil.unixpassword.NewlineEmptyException
| This exception is raised when an empty line separator string is encountered. More...
class | caellion.pycommons.stringutil.unixpassword.InvalidFileFormatException
| This exception is raised when encountering invalid or non-uniform line. More...
class | caellion.pycommons.stringutil.unixpassword.UnixPasswordText
| This class provides methods to read and write to linux-style passwd/shadow files, ability to parse shadow-style lines into dicts and identifying password hashing algorithms used in linux-style hash format. More...

## Namespaces
| caellion.pycommons.stringutil.unixpassword
| This module provides utlilities related to creating, reading, writing and parsing of linux-style passwd/shadow file.